# Pyntegrate

![Run Unit Tests](https://github.com/rtsfred3/pyntegrate/workflows/Run%20Unit%20Tests/badge.svg)

[![CodeQL](https://github.com/rtsfred3/pyntegrate/actions/workflows/codeql-analysis.yml/badge.svg)](https://github.com/rtsfred3/pyntegrate/actions/workflows/codeql-analysis.yml)

Mirrored on [GitLab](https://gitlab.com/rtsfred3/pyntegrate)

## What are C Extensions in Python?

C Extensions allow for native C/C++ code (with a small penalty) to be used within Python. The documentation can be found [here](https://docs.python.org/3/extending/index.html), [here](https://docs.python.org/3/extending/extending.html), and [here](https://docs.python.org/3/c-api/index.html).

## Why use C Extensions?

The main benefit of using C Extensions would be the speed of C, with a slight penalty, when translating between C and Python.

## How to Build or Install

To build from source, use `python3 setup.py build`.

To install from source, use `python3 setup.py install`.

To install using pip, use `pip install pyntegrate`

## Installation

`git clone https://github.com/rtsfred3/pyntegrate.git`

`python3 setup.py install`

### License

```
Copyright 2021 Ryan Fredrickson

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

   http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
```
